@@ -1,7 +1,7 @@
 import os
 import sys
 from dodo_commands.framework import execute_from_command_line
-from dodo_commands.framework.util import create_global_config
+from dodo_commands.framework.config import create_global_config
 
 
 def main():  # noqa
