@@ -33,7 +33,7 @@ if Dodo.is_main(__name__, safe=False):
             cmd_args.extend(["-v", path])
 
         cmd_args.append(args.image)
-        Dodo.runcmd(cmd_args)
+        Dodo.run(cmd_args)
 
     config = ConfigIO().load(load_layers=False)
     config['DOCKER'].setdefault('containers',
