@@ -28,7 +28,7 @@ def _args():
 
 if Dodo.is_main(__name__, safe=True):
     args = _args()
-    Dodo.runcmd([], cwd='.')
+    Dodo.run([], cwd='.')
 """
 
 if Dodo.is_main(__name__, safe=False):
@@ -36,9 +36,9 @@ if Dodo.is_main(__name__, safe=False):
     dest_path = None
     command_path = CommandPath(Dodo.config)
     for item in command_path.items:
-        script_path = os.path.join(item.full_path, args.next_to + ".py")
+        script_path = os.path.join(item, args.next_to + ".py")
         if os.path.exists(script_path):
-            dest_path = os.path.join(item.full_path, args.name + ".py")
+            dest_path = os.path.join(item, args.name + ".py")
 
     if not dest_path:
         raise CommandError("Script not found: %s" % args.next_to)
