@@ -17,8 +17,11 @@ def _args():
 if Dodo.is_main(__name__):
     args = _args()
     if args.key:
-        print("%s" % ruamel.yaml.round_trip_dump(
-            look_up_key(Dodo.config, args.key, '')))
+        contents = look_up_key(Dodo.config, args.key, '')
+        if isinstance(contents, str):
+            print(contents)
+        else:
+            print("%s" % ruamel.yaml.round_trip_dump(contents))
     else:
         content = re.sub(
             r'^([0-9_A-Z]+\:)$',
