@@ -32,6 +32,18 @@ def _ask_to_continue(args, cwd, is_echo, is_confirm):
     return True
 
 
+class DecoratorScope:
+    def __init__(self, decorator_name):
+        self.decorators = Dodo.config['ROOT']['decorators'].setdefault(
+            decorator_name, [])
+
+    def __enter__(self):  # noqa
+        self.decorators.append(Dodo.command_name)
+
+    def __exit__(self, type, value, traceback):  # noqa
+        self.decorators.remove(Dodo.command_name)
+
+
 class Dodo:
     command_name = None
     safe = True
@@ -160,9 +172,9 @@ class Dodo:
         return cls.args
 
     @classmethod
-    def runcmd(cls, args, cwd=None, quiet=False, capture=False):
+    def run(cls, args, cwd=None, quiet=False, capture=False):
         if not hasattr(cls.args, 'echo'):
-            raise CommandError('Dodo.runcmd was called without first calling '
+            raise CommandError('Dodo.run was called without first calling '
                                'Dodo.parse_args.')
         root_node = ArgsTreeNode('original_args', args=args)
         for decorator in cls._get_decorators():
@@ -192,3 +204,10 @@ class Dodo:
                         )
                         print("\n\n%s" % func)
                     return False
+
+    # add alias for the legacy 'runcmd' method
+    runcmd = run
+
+    @classmethod
+    def decorator(cls, decorator_name):
+        return DecoratorScope(decorator_name)
